pub struct MemoryAuthEngine { /* private fields */ }Expand description
In-memory authentication engine using a HashMap.
This is a simple authentication engine that stores credentials in memory. Useful for testing and simple deployments.
Implementations
Sourceimpl MemoryAuthEngine
impl MemoryAuthEngine
Sourcepub fn from_map(credentials: HashMap<String, String>) -> Self
pub fn from_map(credentials: HashMap<String, String>) -> Self
Creates a MemoryAuthEngine from an existing HashMap.
Sourcepub fn from_arc(credentials: Arc<HashMap<String, String>>) -> Self
pub fn from_arc(credentials: Arc<HashMap<String, String>>) -> Self
Creates a MemoryAuthEngine from an Arc
Sourcepub fn from_file(path: &str) -> Result<Self>
pub fn from_file(path: &str) -> Result<Self>
Loads credentials from a file.
The file should be formatted as:
username:password
username2:password2Returns an error if the file cannot be read.