get_crate_root

Function get_crate_root 

pub fn get_crate_root() -> Result<PathBuf, Box<dyn Error>>
Returns the root directory of the crate, using the current executable path as reference.

It works by going up the directory tree until it finds a directory that ends with “target”, which is not the case for the root directory.