pub async fn generate_random_bytes(size: usize) -> Result<Vec<u8>, Error>Expand description
Generates random bytes that can be used to test the file system.
The generated bytes are not guaranteed to be unique, but it uses a good random number generator.