pub async fn generate_random_file( path: impl AsRef<Path>, size_mb: usize, ) -> Result<(), Error>
Generates a random file with the given size in MB.
The file is created in the path provided and in an async manner.